clear('all'); close('all'); 
% transient heat conduction in a slab
%
% dT/dt = d^2 T/ dx^2   
% T(x,0) = 0;          -1 < x < 1
% T(1,t)=T(-1,t) = 1    0 < t
%
% jbr, 9/12/2007
%
global B

ncol = 30;

[x, A, B, q] = colloc (ncol-2, 'left', 'right');

% rescale the collocation points and matrices to [-1,1]
a = 2;
x = a*x - 1;
A = A/a;
B = B/(a*a);
q = q*a;

% initial condition on temperature
T0  = zeros(ncol, 1);


%choose times for output (see Figure 12-1-1 in BSL, 2002)
time = [0.00, 0.01, 0.04, 0.1, 0.2, 0.4, 0.6, 1.0];

% initial condition is zero except at the two ends
T0 = [1; zeros(ncol-2, 1); 1];

[tout, T] = ode15s (@heateq, time, T0);

% plot temperature profiles at output times (don't plot intial condition)
plot(x, T(2:end,:))

table = [x, T(2:end,:)'];
save -ascii tran_slab.dat table 
