clear('all'); close('all'); 
%
% Estimate parameters for the A->B->C model
% jbr,  11/2008

clear all
close all

% attempt to use locally built version of sundials by removing any
% sundials directories from the path except for
% util/common/sundialsTB, then execute the startup_STB script from
% that directory to add the other sundials directories to the path.
p = strsplit (path (), pathsep ());
p = p(cellfun (@(x) ~isempty (x), strfind (p, 'sundials')) ...
      & ~cellfun (@(x) ~isempty (x), ...
                  strfind (p, fullfile ('util', 'common', 'sundialsTB'))));
if (~isempty (p))
  rmpath (p{:});
end
clear p;
if (exist (fullfile ('util', 'common'), 'dir'))
  top_dir = pwd ();
  stb_dir = fullfile (top_dir, 'util', 'common', 'sundialsTB');
else
  top_dir = fullfile (pwd (), '..', '..');

  m_file_dir = fullfile (top_dir, 'octave');
  if (exist (m_file_dir, 'dir'))
    addpath (m_file_dir);
  else
    m_file_dir = fullfile (top_dir, 'matlab');
    if (exist (m_file_dir, 'dir'))
      addpath (m_file_dir);
    end
  end
  sundials_src_dir = fullfile (top_dir, 'sundials-2.5.0', 'sundialsTB');
  maybe_install_STB (sundials_src_dir, m_file_dir);
  stb_dir = fullfile (m_file_dir, 'sundialsTB');
  addpath (stb_dir);
end
startup_STB (stb_dir);
clear top_dir m_file_dir sundials_src_dir stb_dir

global model 

k1 = 2;
k2 = 1;
ca0 = 1;
cb0 = 0;
cc0 = 0;
thetaac = [k1; k2];


tfinal = 6;
nplot = 100;
model.odefcn  = @massbal_ode;
model.tplot   = linspace(0, tfinal, nplot)';
model.param   = thetaac;
model.ic = [ca0; cb0; cc0];

objective.estflag = [1, 2];
objective.paric   = [0.5; 3];
objective.parlb   = [1e-4; 1e-4;];
objective.parub   = [10; 10];

measure.states = [1,2,3];
% load measurements from a file
table = load ('ABC_data.dat');
measure.time = table(:,1);
measure.data = table(:,1+measure.states);

% estimate the parameters
estimates = parest(model, measure, objective);


disp('Estimated Parameters and Bounding Box')
[estimates.parest estimates.bbox]


%plot the model fit to the noisy measurements
figure(1);
plot(model.tplot, estimates.x, measure.time, measure.data, 'o');

% if 2-d, plot confidence ellipse
if (length(objective.estflag) == 2)
  [xe, ye] = ellipse(estimates.Pinv, estimates.b, 100, estimates.parest);
  figure(2); 
  plot(xe, ye)
end

table = [model.tplot, estimates.x'];
save ABC.dat table
